Package: yuima
Type: Package
Title: The YUIMA Project Package for SDEs
Version: 1.15.34
Depends: R(>= 4.1.0), methods, zoo, stats4, utils, expm, cubature,
        mvtnorm
Imports: Rcpp (>= 0.12.1), boot (>= 1.3-2), glassoFast, coda, calculus
        (>= 0.2.0), statmod, Matrix
Authors@R: c(person(given = c("YUIMA", "Project"),
                       family = "Team",
                       role = "aut"),
                person(given = "Yuta",
                       family = "Koike",
                       role = "cre",
                       email = "kyuta@ms.u-tokyo.ac.jp"))
Description: Simulation and Inference for SDEs and Other Stochastic Processes.
License: GPL-2
URL: https://yuimaproject.com
BugReports: https://github.com/yuimaproject/yuima/issues
LinkingTo: Rcpp, RcppArmadillo
NeedsCompilation: yes
RoxygenNote: 7.3.3
Packaged: 2025-12-13 16:06:26 UTC; kyuta
Author: YUIMA Project Team [aut],
  Yuta Koike [cre]
Maintainer: Yuta Koike <kyuta@ms.u-tokyo.ac.jp>
Repository: CRAN
Date/Publication: 2025-12-14 06:10:03 UTC
Built: R 4.6.0; aarch64-apple-darwin23; 2026-04-26 01:30:08 UTC; unix
Archs: yuima.so.dSYM
